@@ -43,6 +43,7 @@
 #include "command.h"
 #include "splash-widget.h"
 #include "util.h"
+#include "gsm-dbus.h"
 #include "gsm-sound.h"
 #include "gsm-gsd.h"
 #include "gsm-proxy.h"
@@ -310,18 +311,6 @@ gsm_shutdown_gconfd (void)
   g_free (command);
 }
 
-static gboolean
-is_later_than_date_of_doom (void)
-{
-  time_t t;
-  struct tm *tm;
-
-  t = time (NULL);
-  tm = localtime (&t);
-
-  return (tm->tm_year >= 105); /* We start on Jan 1 2006 */
-}
-
 int
 main (int argc, char *argv[])
 {
@@ -336,6 +325,7 @@ main (int argc, char *argv[])
   char **versions;
   GConfClient *gconf_client;
   GOptionContext *goption_context;
+  gboolean dbus_daemon_owner;
   
   if (getenv ("GSM_VERBOSE_DEBUG"))
     gsm_set_verbose (TRUE);
@@ -346,7 +336,7 @@ main (int argc, char *argv[])
     {
       int major;
       major = atoi (versions [1]);
-      if ((major % 2) != 0 && is_later_than_date_of_doom ())
+      if ((major % 2) != 0)
 	{
 	  putenv ("G_DEBUG=fatal_criticals");
 	  g_log_set_always_fatal (G_LOG_LEVEL_CRITICAL);
@@ -398,7 +388,10 @@ main (int argc, char *argv[])
   a_t_support = gconf_client_get_bool (gconf_client, ACCESSIBILITY_KEY, NULL);
 
   if (a_t_support)
-    gsm_at_set_gtk_modules ();
+    {
+      gsm_assistive_registry_start ();
+      gsm_at_set_gtk_modules ();
+    }
 
   goption_context = g_option_context_new (_("- Manage the GNOME session"));
   g_option_context_add_main_entries (goption_context, options, GETTEXT_PACKAGE);
@@ -434,6 +427,7 @@ main (int argc, char *argv[])
 
   /* Need DISPLAY set */
   gsm_keyring_daemon_start ();
+  dbus_daemon_owner = gsm_dbus_daemon_start ();
   gsm_gsd_start ();
   
   /* Read the rest of config options */  
@@ -506,6 +500,9 @@ main (int argc, char *argv[])
 
   gsm_keyring_daemon_stop ();
 
+  if (dbus_daemon_owner)
+    gsm_dbus_daemon_stop ();
+
   g_object_unref (gconf_client);
   gsm_shutdown_gconfd ();
 
